/**
 * Based on bootstrap-notify.js v1.0 -- Copyright 2012 Goodybag, Inc.
 */

(function (factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['jquery'], factory);
    } else if (typeof exports === 'object') {
        // Node/CommonJS
        module.exports = factory(require('jquery'));
    } else {
        // Browser globals
        factory(jQuery);
    }
}(function ($) {
	$(function() {
		$('body').append('<div class="page-notify top-center"></div><div class="page-notify bottom-left"></div>');
	});

	var Notification = function (element, options) {
		// Element collection
		this.$element = $(element);
		this.$note = $('<div class="alert"></div>');
		this.options = $.extend(true, {}, $.fn.notify.defaults, options);

		// Setup from options
		if (this.options.transition) {
			if (this.options.transition === 'fade')
				this.$note.addClass('in').addClass(this.options.transition);
			else
				this.$note.addClass(this.options.transition);
		} else
			this.$note.addClass('fade').addClass('in');

		if (this.options.type)
			this.$note.addClass('alert-' + this.options.type);
		else
			this.$note.addClass('alert-success');

		if (!this.options.message && this.$element.data("message") !== '') // dom text
			this.$note.html(this.$element.data("message"));
		else
			this.$note.html(this.options.message);

		if (this.options.closable) {
			var link = $('<a class="close" href="#">&times;</a>');
			link.on('click', $.proxy(onClose, this));
			this.$note.prepend(link);
		}

		return this;
	};

	var onClose = function () {
		this.options.onClose();
		$(this.$note).remove();
		this.options.onClosed();
		return false;
	};

	Notification.prototype.show = function () {
		if (this.options.fadeOut)
			this.$note.delay(this.options.fadeOut).fadeOut('slow', $.proxy(onClose, this));

		this.$element.append(this.$note);
		this.$note.fadeIn();
	};

	Notification.prototype.hide = function () {
		if (this.options.fadeOut)
			this.$note.delay(this.options.fadeOut).fadeOut('slow', $.proxy(onClose, this));
		else
			onClose.call(this);
	};

	$.fn.notify = function (options) {
		return new Notification(this, options);
	};

	$.fn.notify.defaults = {
		type: 'success',
		closable: true,
		transition: 'fade',
		fadeOut: 5000,
		message: null,
		onClose: function () {
		},
		onClosed: function () {
		}
	};
}));